==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/frm_main_calendar_dayweek.js <==
_me = frm_main_calendar_dayweek.prototype;
function frm_main_calendar_dayweek(){};

_me.__constructor = function() {

	var me = this;
	this.__step = 0;

	this.previous._onclick = function() {
		var range = me.calendar._range();
		var dStart = range['start']-me.__step;
		
		me.calendar._range(dStart, range['end']-me.__step);
		me._updateLabel(dStart);

		me._serverSort();
	}
	this.next._onclick = function() {
		var range = me.calendar._range();
		var dStart = range['start']+me.__step;

		me.calendar._range(dStart, range['end']+me.__step);
		me._updateLabel(dStart);
		me._serverSort();
	}
	
};

_me._setDayView = function(_date) {
	this.__step = 1;
	
	this.__date = _date || new Date();
	
	var hours = this.__getWorkingHours();
	var julianDate = this.__date.getJulianDate();
	this._updateLabel(julianDate);

	this.calendar._range(julianDate, julianDate, hours['start'], hours['end']);
};

_me._updateLabel = function(juldate) {
	var oDate = new Date();
	oDate.setGWTime(juldate);

	if (this.__step == 1){
		//var aDays = ['SHORT_DAYS::SUNDAY','SHORT_DAYS::MONDAY','SHORT_DAYS::TUESDAY','SHORT_DAYS::WEDNESDAY','SHORT_DAYS::THURSDAY','SHORT_DAYS::FRIDAY','SHORT_DAYS::SATURDAY'];
		var months = [
			"months::january","months::february","months::march","months::april","months::may",
			"months::june","months::july","months::august","months::september","months::october",
			"months::november","months::december"
			];
		              //getLang(aDays[oDate.getDay()]) +' '+
		this.label._value(oDate.getDate() +' '+ getLang(months[oDate.getMonth()]) +' '+ oDate.getFullYear());
//		this.label2._value(getLang('EVENT_VIEW::WEEK_LABEL') + ' ' + oDate.getWeekOfYear() + ' / ' + oDate.getFullYear());
	}
	else{
		this.label._value(getLang('EVENT_VIEW::WEEK_LABEL') + ' ' + oDate.getWeekOfYear() + ' / ' + oDate.getFullYear());
		//this.label2._value('');
	}
};

_me._setWeekView = function(_date) {
	this.__step = 7;
	this.__date = _date || new Date();
	
	var nStartDay = this.__getStartDay();

	if (nStartDay <= this.__date.getDay())
		var fromJulianDate = (new Date(this.__date.getTime() - (this.__date.getDay()-nStartDay)*3600000*24)).getJulianDate();
	else
		var fromJulianDate = (new Date(this.__date.getTime() - (this.__date.getDay()-nStartDay+7)*3600000*24)).getJulianDate();

	var hours = this.__getWorkingHours();
	this._updateLabel(fromJulianDate);

	this.calendar._range(fromJulianDate, fromJulianDate+6, hours['start'], hours['end']);
};

==> IceWarpServer-10.0.6_RHEL5.tar.gz: html/webmail/client/inc/frm_main_calendar_dayweek.js <==
_me = frm_main_calendar_dayweek.prototype;
function frm_main_calendar_dayweek(){};

_me.__constructor = function() {

	var me = this;
	this.__step = 0;

	this.previous._onclick = function() {
		var range = me.calendar._range();
		var dStart = range['start']-me.__step;
		
		me.calendar._range(dStart, range['end']-me.__step);
		me._updateLabel(dStart);

		me._serverSort();
	}
	this.next._onclick = function() {
		var range = me.calendar._range();
		var dStart = range['start']+me.__step;

		me.calendar._range(dStart, range['end']+me.__step);
		me._updateLabel(dStart);
		me._serverSort();
	}
	
};

_me._setDayView = function(_date) {
	this.__step = 1;
	
	this.__date = _date || new Date();
	
	var hours = this.__getWorkingHours();
	var julianDate = this.__date.getJulianDate();
	this._updateLabel(julianDate);

	this.calendar._range(julianDate, julianDate, hours['start'], hours['end']);
};

_me._updateLabel = function(juldate) {
	var oDate = new Date();
	oDate.setGWTime(juldate);

	if (this.__step == 1){
		//var aDays = ['SHORT_DAYS::SUNDAY','SHORT_DAYS::MONDAY','SHORT_DAYS::TUESDAY','SHORT_DAYS::WEDNESDAY','SHORT_DAYS::THURSDAY','SHORT_DAYS::FRIDAY','SHORT_DAYS::SATURDAY'];
		var months = [
			"months::january","months::february","months::march","months::april","months::may",
			"months::june","months::july","months::august","months::september","months::october",
			"months::november","months::december"
			];

		this.label._value(oDate.getDate() +' '+ getLang(months[oDate.getMonth()]) +' '+ oDate.getFullYear());
	}
	else{
		var juldate = oDate.getJulianDate(),
			new_year = new Date(oDate.getFullYear(),0,1),
			diff = juldate - new_year.getJulianDate();
			diff += new_year.getDay();

		var out = Math.floor(diff / 7) + 1;

		// ISO 8601
		if (out == 53 && new_year.getDay()<5)
			this.label._value(getLang('EVENT_VIEW::WEEK_LABEL') + ' 1 / ' + (parseInt(oDate.getFullYear(),10)+1));
		else
			this.label._value(getLang('EVENT_VIEW::WEEK_LABEL') + ' ' + out + ' / ' + oDate.getFullYear());
	}
};

_me._setWeekView = function(_date) {
	this.__step = 7;
	this.__date = _date || new Date();
	
	var nStartDay = this.__getStartDay();

	if (nStartDay <= this.__date.getDay())
		var fromJulianDate = (new Date(this.__date.getTime() - (this.__date.getDay()-nStartDay)*3600000*24)).getJulianDate();
	else
		var fromJulianDate = (new Date(this.__date.getTime() - (this.__date.getDay()-nStartDay+7)*3600000*24)).getJulianDate();

	var hours = this.__getWorkingHours();
	this._updateLabel(fromJulianDate);

	this.calendar._range(fromJulianDate, fromJulianDate+6, hours['start'], hours['end']);
};
